@@ -1,4 +1,5 @@
 import asyncio
+import dataclasses
 import inspect
 from contextlib import contextmanager
 from copy import deepcopy
@@ -217,6 +218,7 @@ def is_scalar_field(field: ModelField) -> bool:
         field.shape == SHAPE_SINGLETON
         and not lenient_issubclass(field.type_, BaseModel)
         and not lenient_issubclass(field.type_, sequence_types + (dict,))
+        and not dataclasses.is_dataclass(field.type_)
         and not isinstance(field_info, params.Body)
     ):
         return False
